@@ -1,4 +1,4 @@
-def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interfaces_and_types=False):
+def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interfaces_and_types=False, print_width=120):
     from collections import defaultdict
     if not categorize:
         return_list = []
@@ -75,10 +75,11 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
             checks_['iterable'] = False
         return_list.append([checks_])
 
-    return return_list
+    from pprint import pprint
+    pprint(return_list, compact=True, width=print_width)
 
 
-def two_way(operation, opposite=False, iterators=False):
+def two_way(operation, opposite=False, iterators=False, print_width=120):
     import warnings
     warnings.filterwarnings("ignore")
     import re, keyword
@@ -160,10 +161,11 @@ def two_way(operation, opposite=False, iterators=False):
                             succeeded[a].add(b)
                     except:
                         failed[a].add(b)
-    return [{'succeeded': succeeded}]
+    from pprint import pprint
+    pprint([{'succeeded': succeeded}], compact=True, width=print_width)
 
 
-def operator_check(left_argument, right_argument, show_failed=False):
+def operator_check(left_argument, right_argument, show_failed=False, print_width=120):
     import warnings
     warnings.filterwarnings("ignore")
     failed = set()
@@ -183,7 +185,8 @@ def operator_check(left_argument, right_argument, show_failed=False):
     returned_dictionary = {'succeeded': succeeded}
     if show_failed:
         returned_dictionary['failed'] = failed
-    return returned_dictionary
+    from pprint import pprint
+    pprint(returned_dictionary, compact=True, width=print_width)
 
 
 extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs', 'all', 'any',
